% Batch file for the PCA analysis of the case study 1 relating alcohol
% consumption and life quality.
% the dataset is constituted by 5 features that are saved in the cell
% "variables":
%   liquor consumption
%   wine consumption
%   beer consumption
%   life expectancy
%   heart disease rate
% The data are collected for 10 different countries (that are described in
% the cell variable "countries"
%% Step 1: Load data
load data_alcohol.mat
%% Step 3: Perform an unity variance transformation
% command mapstd performs a row-wise unity transformation. Since the
% variables are arranged along the columns, one needs to transpose the data
% at first. The result of the transformation should be transposed again 
datastd=mapstd(data')';
%% Step3: Accomplish the PCA algorithm with the function pca
[coeff,score,latent]=pca(datastd);
% The outputs of the function are:
%   - coeff (the loadings matrix)
%   - score (the scores matrix)
%   - latent (eigenvalues of the covariance matrix of X, i.e. the principal
%   component variance)
%% Step 4: Graphical representation of the scores variance
% see page 8 of slides
bar(latent,'Linewidth',1.5)
xlabel('Principal component')
ylabel('Principal component variance')
% Graphical representation of the scores variance
hold on
plot([0,6],[1 1],'k--','Linewidth',1.5)
% plotting the line y=1, representing a reasonable threshold value for the
% selection of the significant principal components
% N.B. This is a threshold value that was reasonable to assume after unity
% variance transformation was accomplished: artificial variables (scores)
% showing variance greater than the ones collected by the original ones (=1) 
% are considered to be significant 
%% Step 5: Plotting Scores 
% see page 9 on slides
figure
% Create a new figure
plot(score(:,1),score(:,2),'o','Markersize',10,'Linewidth',1.5)
% instructions to add labels at the points
dx=0.2;
dy=0.2;
text(score(:,1)-dx,score(:,2)-dy,countries,'Fontsize',10)
%% Step 6: Residual representation
% see page 10 on slides
figure
% Create a new figure
residuals=datastd-score(:,1:2)*coeff(:,1:2)';
% Computation of the residuals that are not captured by the first two
% principal components of the PCA model
boxplot(residuals',countries)
%% Step 7: Loadings analysis
% see page 11 on slides
figure
% Create a new figure
plot(coeff(:,1),coeff(:,2),'o','Markersize',10,'Linewidth',1.5)
xlabel('Loadings on PC1')
ylabel('Loadings on PC2')
% instructions to add labels on the points
text(coeff(:,1)+0.2*dx,coeff(:,2)+0.2*dy,variables,'Fontsize',12)
axis([-0.8 0.8 -0.8 0.8])
%% Step 8: biplot graphic
% see page 12 on slides
% It is possible to use the Matlab default function "bibplot" 
figure
biplot(coeff(:,1:2),'Linewidth',2.0,'Scores',score(:,1:2),'Markersize',12,'Varlabels',variables);
% Alternative representation of the biplot (more effective)
figure
hold on
for i=1:5
quiver(0,0,5*coeff(i,1),5*coeff(i,2),'Linewidth',1.5);
end
% Loading representation with arrows
text(5*coeff(:,1)+dx,5*coeff(:,2)+dy,variables,'Fontsize',12)
% Scores representation
plot(score(:,1),score(:,2),'o','Markersize',10,'Linewidth',1.5)
text(score(:,1)-dx,score(:,2)-dy,countries,'Fontsize',10)
xlabel('PC1')
ylabel('PC2')